@@ -3,6 +3,8 @@ from .database import Database
 from .delegated import Delegated
 from .enterprise import Enterprise
 from .get_token import GetToken
+from .logout import Logout
 from .passwordless import Passwordless
+from .revoke_token import RevokeToken
 from .social import Social
 from .users import Users
